MessagePipe

Struct MessagePipe 

struct MessagePipe<T> {
    tx: SyncSender<T>,
    rx: Receiver<T>,
}
🔬This is a nightly-only experimental API. (proc_macro_internals)
A message pipe used for communicating between server and client threads.

Fields

tx: SyncSender<T>
🔬This is a nightly-only experimental API. (proc_macro_internals)
rx: Receiver<T>
🔬This is a nightly-only experimental API. (proc_macro_internals)

Implementations

Source

impl<T> MessagePipe<T>

fn new() -> (Self, Self)

🔬This is a nightly-only experimental API. (proc_macro_internals)

Creates a new pair of endpoints for the message pipe.

fn send(&mut self, value: T)

🔬This is a nightly-only experimental API. (proc_macro_internals)

Send a message to the other endpoint of this pipe.

fn recv(&mut self) -> Option<T>

🔬This is a nightly-only experimental API. (proc_macro_internals)

Receive a message from the other endpoint of this pipe.

Returns None if the other end of the pipe has been destroyed, and no message was received.